@@ -1,4 +1,4 @@
-from dataclasses import make_dataclass, field, asdict
+from dataclasses import make_dataclass, field, asdict, fields
 import json
 
 from pydantic import create_model, ValidationError
@@ -11,10 +11,14 @@ def dataclass_to_model(dc):
 
 
 def serialize(i, to_string=False):
+    d = asdict(i)
+    version = getattr(i, '__version__', 0)
+
     if hasattr(i, "__pydantic_model__"):
-        j = i.__pydantic_model__(**asdict(i)).json()
-    else:
-        j = json.dumps(asdict(i), default=pydantic_encoder)
+        d = i.__pydantic_model__(**d).dict()
+
+    d['__version__'] = version
+    j = json.dumps(d, default=pydantic_encoder)
     if to_string:
         return j
 
@@ -31,3 +35,13 @@ def extract_schema(name, entity, include=None):
         (f[0], f[1]) for f in fields
     )
     return dataclass(cls)
+
+
+def filter_dict_to_schema(entity: dataclass, payload: dict):
+    fs = [
+        f.name for f in fields(entity)
+    ]
+    return dict(
+        (key, value) for key, value in payload.items()
+        if key in fs
+    )
